import { ChangeDetectionStrategy, Component, inject, OnInit } from '@angular/core';
import { Router } from '@angular/router';
import { AuthService } from '../../service/auth.service';
import { OAuthService } from 'angular-oauth2-oidc';

@Component({
  selector: 'app-login-success',
  standalone: true,
  imports: [],
  templateUrl: './login-success.component.html',
  styleUrl: './login-success.component.css',
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export default class LoginSuccessComponent implements OnInit {
  private authService: AuthService = inject(AuthService);
  private oauthService: OAuthService = inject(OAuthService);
  private router: Router = inject(Router);

  async ngOnInit() {
    try {
      // Check if we're authenticated
      if (this.oauthService.hasValidAccessToken()) {
        this.router.navigate(['/home']);
      } else {
        // Wait a bit and check if we've been authenticated in the meantime
        setTimeout(() => {
          if (this.oauthService.hasValidAccessToken() || this.authService.getUser()) {
            this.router.navigate(['/home']);
          } else {
            this.router.navigate(['/']);
          }
        }, 3000);
      }
    } catch (err) {
      console.error('Error during login callback:', err);
      // Wait a bit in case token processing is happening elsewhere
      setTimeout(() => {
        if (this.authService.isLoggedIn()) {
          this.router.navigate(['/home']);
        } else {
          this.router.navigate(['/']);
        }
      }, 3000);
    }
  }
}
